<template>
  <el-dialog
    v-dialogDrag
    :title="title"
    :visible="visible"
    :before-close="handleClose"
    :close-on-click-modal="false"
    :append-to-body="true"
    v-if="visible"
    width="40%"
    :class="[reqLoading ? 'dialog-box' : '']"
  >
    <div
      v-loading="reqLoading"
      element-loading-text="加载中..."
      element-loading-spinner="el-icon-loading"
      element-loading-background="rgba(255, 255, 255, 1)"
    >
      <el-form
        ref="formInfo"
        :model="parameter"
        label-width="60px"
        :rules="rules"
      >
        <el-form-item
          prop="name"
          required
          label="区县"
        >
          <el-cascader
            placeholder="请选择区县"
            :options="treeData"
            v-model="parameter.name"
            style="width: 100%"
            filterable
            :props="{ multiple:true, value: 'id', label: 'name', children: 'children', }"
            clearable></el-cascader>
        </el-form-item>
      </el-form>
    </div>
    <div
      slot="footer"
      class="dialog-footer"
      :style="reqLoading ? 'position: relative;z-index: -1;' : ''"
    >
      <el-button type="primary" @click="onConfirm">发布</el-button>
      <el-button @click="handleClose">取消</el-button>
    </div>
  </el-dialog>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import org from '@/api/org'
import utils from '@/utils'
import countyApi from '@/api/ReformSituation/countyApi'
export default {
  name: 'countyDialog',
  mixins: [TableMixin],
  data() {
    return {
      visible: false,
      reqLoading: false,
      title:'',
      parameter:{
        name:[]
      },
      rules:{
        name: [{ required: true, message: '区县不能为空', trigger: 'change' }],
      },
      treeData: []
    }
  },
  created(){
    this.setTreeData()
  },
  methods: {
    setTreeData() {
      let data = JSON.parse(sessionStorage.getItem('responsibilityTree'))
      if (data) {
        this.treeData = data
      } else {
        org.getByParentAndDemToTree({
          orgKind: 'ogn',
        }).then((res) => {
          this.treeData = res ? utils.tile2nest(res) : utils.tile2nest([])
          sessionStorage.setItem(
            'responsibilityTree',
            JSON.stringify(this.treeData)
          )
        })
      }
    },
    upDate(title){
      this.parameter.name = []
      this.title = title
      this.visible = true
    },
    handleClose(){
      this.visible = false
    },
    onConfirm(){
      this.$refs['formInfo'].validate((valid) => {
        if (valid) {
          let lastElements = this.parameter.name.map(arr => arr[arr.length - 1]);
          countyApi.districtPutOut(lastElements).then(res => {
            if (res.state) {
              this.$message.success('发布成功')
              this.handleClose()
              this.$emit('confirm')
            }
          })
        }
      })
    },
  },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';
/deep/ .el-dialog__body {
  padding: 15px 20px;
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;
  margin-left: 4px;
  margin-bottom: 4px;
  margin-top: 14px;
  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }

  /deep/ i,
  span {
    font-size: 14px;
  }
}

.dialog-flex{
  display: flex;
  align-items: center;
}
.dialog-title{
  display: flex;
  align-items: center;
  line-height: 3;
  margin:10px 30px 0 20px;
}
.title-number{
  font-size: 16px;
}
.title-style{
  font-size: 16px;
  font-weight: 700;
}
.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;
  margin-left: 4px;
  margin-bottom: 4px;
  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }

  /deep/ i,
  span {
    font-size: 14px;
  }
}
</style>
